@@ -121,7 +121,7 @@ class StaticGenerator(object):
         if path.endswith('/'):
             path = '%sindex.html' % path
             
-        fn = os.path.join(self.web_root, path.lstrip('/'))
+        fn = os.path.join(self.web_root, path.lstrip('/')).encode('utf-8')
         return fn, os.path.dirname(fn)
         
     def publish_from_path(self, path, content=None):
