@@ -15,12 +15,12 @@ class StaticGeneratorMiddleware(object):
         
     """
     urls = tuple([re.compile(url) for url in settings.STATIC_GENERATOR_URLS])
+    gen = StaticGenerator()
     
     def process_response(self, request, response):
         if response.status_code == 200:
             for url in self.urls:
                 if url.match(request.path):
-                    gen = StaticGenerator()
-                    gen.publish_from_path(request.path, response.content)
+                    self.gen.publish_from_path(request.path, response.content)
                     break
         return response
\ No newline at end of file
